## README assignment1 gruppo CMST

#### COMPONENTI GRUPPO:
* Davide Monti
* Samuele Campanella
* Lorenzo Titta
* Davide Soldati

#### DESCRIZIONE APP:
L'applicazione permette ad un utente di aggiungere, modificare o rimuovere attività da un elenco.

#### PIPELINE:
###### Pipeline development:
In questa pipeline viene eseguita la fase di test. Ovvero, dopo l'installazione dei requisiti necessari, viene verificata la qualità del codice prodotto.
Oltre a ciò vengono anche eseguiti UnitTest e IntegrationTest.

###### Pipeline release WIP:
